summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/effects.cc
diff options
context:
space:
mode:
Diffstat (limited to 'crawl-ref/source/effects.cc')
-rw-r--r--crawl-ref/source/effects.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/crawl-ref/source/effects.cc b/crawl-ref/source/effects.cc
index fd5c9b0fc9..65245158fa 100644
--- a/crawl-ref/source/effects.cc
+++ b/crawl-ref/source/effects.cc
@@ -3620,10 +3620,10 @@ void handle_time(long time_delta)
}
else
{
// If Chronos has slowed your biology, disease might
// not actually do anything.
if (one_chance_in(30)
- && !(you.religion == GOD_CHRONOS
+ && !(you.religion == GOD_CHEIBRIADOS
&& piety_rank(you.piety) >= 1
&& coinflip()))
{
@@ -3620,10 +3620,10 @@ void handle_time(long time_delta)
else
{
- // If Chronos has slowed your biology, disease might
+ // If Cheibriados has slowed your biology, disease might
// not actually do anything.
if (one_chance_in(30)